=====
Magic Tables
=====

Magic Tables is a Django app to turn QuerySets to any kind of table.

Detailed documentation is in the "docs" directory.

Quick start
-----------

1. Add "magic_talbes" to your INSTALLED_APPS setting like this:

    INSTALLED_APPS = [
        ...
        'magic_talbes',
    ]
